==> phoenix-0.1.2.tar.gz: phoenix-0.1.2/scripts/main.tcl <==
################################################################
# Modifications beyond tkWWW 0.9 are Copyright 1993, 1994 by
# The University of Chicago Biological Sciences Division, Academic Computing
# Philip Stylianos
# Lee Newberg
################################################################

#cmdtrace on
## main.tcl main file for Phoenix user interface
## ==============
## Copyright (C) 1992-1993
## Global Network Academy
## Macvicar Institute for Educational Software Development
##
## See the file COPYRIGHT for conditions 

## *************************
## This is the main file for Phoenix
## *************************

## *************************
## This is the directory containing the source code
## *************************

global env

# hack
set lower " abcdefghijklmnopqrstuvwxyz"
set ordinal(1) ""
for {set tree 1} {$tree <= 26} {incr tree} {
	set frog [string index $lower $tree]
	set ordinal($frog) $tree
	set ordinal($tree) $frog
}

# CONFIGURATION: 
# Below, replace /opt/phoenix with whatever the root of your
# Phoenix source tree is.

# Get environment variables from the shell and transfer them to 
# Tcl global variables.  Where none, use the default.

foreach variable [list \
    {PHOENIX_DIR envphxdir /opt/phoenix} \
    {TKWWW_DIR tkwwwdir $envphxdir/WWW/TkWWW/Tcl} \
    {PHXMGR_DIR phxsrcdir $envphxdir/Phxmgr} \
    {PHXBIN_DIR phxbindir $envphxdir/bin} \
    {HOME envhome ""} \
    {LOGNAME envlogname ""} \
    {WWW_HOME envwwwhome ""}] \
{
    set shell [lindex $variable 0]
    set tcl [lindex $variable 1]
    set default [lindex $variable 2]
    global $tcl
    catch {unset $tcl}
    if {[catch {set $tcl $env($shell)}] && $default != ""} {
	eval "set $tcl $default"
    }
}

set tkW3SourcePath $tkwwwdir

## *************************
## end of user defined parameters
## *************************

# Add the source path to the auto load table
set auto_path "$tkW3SourcePath $phxsrcdir $auto_path"

## *************************
## Load in all the configurations
## *************************
phxW3ConfigInitialize

set phxW3Version "0.0"

## *************************
## Parse the command line
## *************************


tkW3ParseArgs $argv

## *************************
## Startup the server
## Do this early do that the server has time to "warm up" 
## before we actually use it
## *************************

tkW3NavigateStartupServer

# ************************
# Check for incompatibilties between frontend and backend
# ************************

phxW3VersionVerify $phxW3Version

# *************************
# Window management and Interface code 
# *************************
wm title . "Phoenix Web Browser"
wm minsize . 0 0
wm iconbitmap . @$tkW3SourcePath/bitmap/logo

PhxApp_init

proc PhxApp_name_window {} {

	if { [winfo exists .titles.title_entry] } {
		return [.titles.title_entry get 1.0 end]
	}

	return "Web window"
}

pack configure \
    [ tkW3MenuMakeMenus .menu $tkW3ConfigMenus ] \
    -side top -fill x
pack configure [label .status -relief flat -height 1 -bd 2 -bg white] \
    -in .menu -side right
pack configure \
    [ tkW3OutputMakeButtons .buttons $tkW3ConfigButtons ] \
    -side left -fill y
pack configure \
    [ tkW3OutputMakeEntries .style $tkW3ConfigEntries ] \
    [ tkW3OutputMakeTitleBox .titles ] \
    [ tkW3OutputMakeToggles .toggles $tkW3ConfigToggles ] \
    -side top -fill x
pack configure [frame .space1 -width 4 -relief flat] -side left -fill y
pack configure [tkW3OutputMakeScrollbars] -side left -fill y
pack configure [frame .space2 -width 4 -relief flat] -side left -fill y
pack configure [frame .f] -side top -fill both -expand yes

. configure -cursor right_ptr
.f configure -cursor left_ptr
bind .f <Button-1> {phxW3SelectionSetFocus [phxW3WidgetLeft end] end}

	.menu.file.m disable Print


## *************************
## source user configuration file
## *************************

catch {source "$envhome/.phoenix-config"}

## *************************
## Do initializations
## *************************

tkW3OutputCursorWait
tkW3NavigateInitialize
phxW3FontInitialize
tkW3FileInitialize
phxW3FileboxInitialize
tkW3EditInitialize
tkW3HistoryInitialize
tkW3PanInitialize
tkW3HelpInitialize
#tkW3BookmarksInitialize
phxW3HtInitialize
phxW3HotlistInitialize
phxW3FormsInitialize
phxW3SelectionInitialize
phxW3ClipboardInitialize
phxW3AnchorInitialize

## *************************
## GUI is created
## Set the welcome message and
## Jump to the first page
## *************************

if {$tkW3ParseArgsShowInfo != 0} {
	tkW3HelpAbout
}

phxW3ModeGoto $tkW3ConfigStartPage

tkW3EditBind .f
focus default .f

tkW3OutputCursorNormal

==> phoenix-0.1.4.tar.gz: phoenix-0.1.4/scripts/main.tcl <==
################################################################
# Modifications beyond tkWWW 0.9 are Copyright 1993, 1994 by
# The University of Chicago Biological Sciences Division, Academic Computing
# Philip Stylianos
# Lee Newberg
################################################################

#cmdtrace on
## main.tcl main file for Phoenix user interface
## ==============
## Copyright (C) 1992-1993
## Global Network Academy
## Macvicar Institute for Educational Software Development
##
## See the file COPYRIGHT for conditions 

## *************************
## This is the main file for Phoenix
## *************************

## *************************
## This is the directory containing the source code
## *************************

global env

# hack
set lower " abcdefghijklmnopqrstuvwxyz"
set ordinal(1) ""
for {set tree 1} {$tree <= 26} {incr tree} {
	set frog [string index $lower $tree]
	set ordinal($frog) $tree
	set ordinal($tree) $frog
}

# Get environment variables from the shell and transfer them to 
# Tcl global variables.  Where none, use the default.

foreach variable [list \
    {PHOENIX_DIR envphxdir /opt/phoenix} \
    {TKWWW_DIR tkwwwdir $envphxdir/WWW/TkWWW/Tcl} \
    {PHXMGR_DIR phxsrcdir $envphxdir/Phxmgr} \
    {PHXBIN_DIR phxbindir $envphxdir/bin} \
    {HOME envhome ""} \
    {LOGNAME envlogname ""} \
    {WWW_HOME envwwwhome ""}] \
{
    set shell [lindex $variable 0]
    set tcl [lindex $variable 1]
    set default [lindex $variable 2]
    global $tcl
    catch {unset $tcl}
    if {[catch {set $tcl $env($shell)}] && $default != ""} {
	eval "set $tcl $default"
    }
}

set tkW3SourcePath $tkwwwdir

## *************************
## end of user defined parameters
## *************************

# Add the source path to the auto load table
set auto_path "$tkW3SourcePath $phxsrcdir $auto_path"

## *************************
## Load in all the configurations
## *************************
phxW3ConfigInitialize

set phxW3Version "0.0"

## *************************
## Parse the command line
## *************************


tkW3ParseArgs $argv

## *************************
## Startup the server
## Do this early do that the server has time to "warm up" 
## before we actually use it
## *************************

tkW3NavigateStartupServer

# ************************
# Check for incompatibilties between frontend and backend
# ************************

phxW3VersionVerify $phxW3Version

# *************************
# Window management and Interface code 
# *************************
wm title . "Phoenix WWW Editor"
wm iconname . "Phoenix WWW Editor"
wm minsize . 0 0
wm iconbitmap . @$tkW3SourcePath/bitmap/logo

PhxApp_init

proc PhxApp_name_window {} {

	if { [winfo exists .titles.title_entry] } {
		return [.titles.title_entry get 1.0 end]
	}

	return "Web window"
}

pack configure \
    [ tkW3MenuMakeMenus .menu $tkW3ConfigMenus ] \
    -side top -fill x
pack configure [label .status -relief flat -height 1 -bd 2 -bg white] \
    -in .menu -side right
pack configure \
    [ tkW3OutputMakeButtons .buttons $tkW3ConfigButtons ] \
    -side left -fill y
pack configure \
    [ tkW3OutputMakeEntries .style $tkW3ConfigEntries ] \
    [ tkW3OutputMakeTitleBox .titles ] \
    [ tkW3OutputMakeToggles .toggles $tkW3ConfigToggles ] \
    -side top -fill x
pack configure [frame .space1 -width 4 -relief flat] -side left -fill y
pack configure [tkW3OutputMakeScrollbars] -side left -fill y
pack configure [frame .space2 -width 4 -relief flat] -side left -fill y
pack configure [frame .f] -side top -fill both -expand yes

. configure -cursor right_ptr
.f configure -cursor left_ptr
bind .f <Button-1> {phxW3SelectionSetFocus [phxW3WidgetLeft end] end}

	.menu.file.m disable Print


## *************************
## source user configuration file
## *************************

catch {source "$envhome/.phoenix-config"}

## *************************
## Do initializations
## *************************

tkW3OutputCursorWait
tkW3NavigateInitialize
phxW3FontInitialize
tkW3FileInitialize
phxW3FileboxInitialize
tkW3EditInitialize
tkW3HistoryInitialize
tkW3PanInitialize
tkW3HelpInitialize
#tkW3BookmarksInitialize
phxW3HtInitialize
phxW3HotlistInitialize
phxW3FormsInitialize
phxW3SelectionInitialize
phxW3ClipboardInitialize
phxW3AnchorInitialize

## *************************
## GUI is created
## Set the welcome message and
## Jump to the first page
## *************************

if {$tkW3ParseArgsShowInfo != 0} {
	tkW3HelpAbout
}

phxW3ModeGoto $tkW3ConfigStartPage

tkW3EditBind .f
focus default .f

tkW3OutputCursorNormal
